@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import sys
-import os.path
+import os
 import logging
 
 # our local ...
@@ -60,6 +60,11 @@ if DEBUG or (config_vars['debug'] == 'on'):
     file_logger.setLevel('DEBUG')
     file_logger.info("(Note: logging set to debug level.)")
 
+# check we are running as root user (sudo)
+if os.geteuid() != 0:
+    file_logger.error("Not running as root. Run using 'sudo' if running on CLI, or add to crontab using 'sudo crontab -e' for normal, schduled operation...exiting.")
+    sys.exit()
+
 # check all our os-level cmds are available
 if not check_os_cmds(file_logger):
     file_logger.error("Missing OS command....exiting.")
@@ -253,7 +258,7 @@ def main():
     if config_vars['http_test_enabled'] == 'yes' and config_vars['test_issue'] == False:
 
         http_obj = HttpTester(file_logger, platform=platform)
-        tests_passed = http_obj.run_tests(status_file_obj, config_vars, exporter_obj, watchdog_obj)
+        tests_passed = http_obj.run_tests(status_file_obj, config_vars, exporter_obj, watchdog_obj, check_correct_mode_interface,)
 
         if tests_passed:
             poll_obj.http('Completed')
